@@ -378,6 +378,7 @@ static struct prefs vars[] = {
 	{"mail_check", PREFS_OFFINT (mail_check), TYPE_BOOL},
 	{"mainwindow_height", PREFS_OFFINT (mainwindow_height), TYPE_INT},
 	{"mainwindow_left", PREFS_OFFINT (mainwindow_left), TYPE_INT},
+	{"mainwindow_save", PREFS_OFFINT (mainwindow_save), TYPE_BOOL},
 	{"mainwindow_top", PREFS_OFFINT (mainwindow_top), TYPE_INT},
 	{"mainwindow_width", PREFS_OFFINT (mainwindow_width), TYPE_INT},
 	{"max_auto_indent", PREFS_OFFINT (max_auto_indent), TYPE_INT},
@@ -446,6 +447,7 @@ static struct prefs vars[] = {
 	{"throttlemeter", PREFS_OFFINT (throttlemeter), TYPE_INT},
 	{"timestamp", PREFS_OFFINT (timestamp), TYPE_BOOL},
 	{"timestamp_logs", PREFS_OFFINT (timestamp_logs), TYPE_BOOL},
+	{"timestamp_log_format", PREFS_OFFSET (timestamp_log_format), TYPE_STR},
 	{"tint", PREFS_OFFINT (tint), TYPE_BOOL},
 	{"tint_blue", PREFS_OFFINT (tint_blue), TYPE_INT},
 	{"tint_green", PREFS_OFFINT (tint_green), TYPE_INT},
@@ -519,7 +521,9 @@ load_config (void)
 	prefs.dialog_width = 300;
 	prefs.dialog_height = 100;
 	prefs.dcc_send_fillspaces = 1;
+	prefs.mainwindow_save = 1;
 	strcpy (prefs.stamp_format, "[%H:%M:%S] ");
+	strcpy (prefs.timestamp_log_format, "%b %d %H:%M:%S ");
 
 #ifdef	USE_JCODE
 	locale = setlocale (LC_CTYPE, "");
