@@ -34,7 +34,7 @@
 
 
 static void
-ctcp_reply (void *sess, char *tbuf, char *nick, char *word[],
+ctcp_reply (session *sess, char *tbuf, char *nick, char *word[],
 				char *word_eol[], char *conf)
 {
 	auto_insert (tbuf, conf, word, word_eol, "", "", word_eol[5], "", "", nick);
@@ -43,7 +43,7 @@ ctcp_reply (void *sess, char *tbuf, char *nick, char *word[],
 }
 
 static int
-ctcp_check (void *sess, char *tbuf, char *nick, char *word[],
+ctcp_check (session *sess, char *tbuf, char *nick, char *word[],
 				char *word_eol[], char *ctcp)
 {
 	int ret = 0;
@@ -81,13 +81,12 @@ handle_ctcp (struct session *sess, char *outbuf, char *to, char *nick,
 
 	if (!strncasecmp (msg, "VERSION", 7) && !prefs.hidever)
 	{
-		sprintf (outbuf,
-					"NOTICE %s :\001VERSION xchat "VERSION
-					" %s\001\r\n", nick, get_cpu_str ());
+		sprintf (outbuf, "NOTICE %s :\001VERSION xchat "VERSION" %s\001\r\n",
+					nick, get_cpu_str ());
 		tcp_send (sess->server, outbuf);
 	}
 
-	if (!ctcp_check ((void *) sess, outbuf, nick, word, word_eol, word[4] + 2))
+	if (!ctcp_check (sess, outbuf, nick, word, word_eol, word[4] + 2))
 	{
 		if (!strncasecmp (msg, "ACTION", 6))
 		{
