@@ -1284,13 +1284,26 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
 			dcc->nick = strdup (nick);
 			if (prefs.autodccsend)
 			{
-				/* don't resume the same file from two people! */
-				if (prefs.autoresume && dcc->resumable &&
-					 !find_dcc (NULL, dcc->file, TYPE_RECV))
+				if (prefs.autoresume && dcc->resumable)
 				{
+					/* don't resume the same file from two people! */
+					GSList *list = dcc_list;
+					struct DCC *d;
+					while (list)
+					{
+						d = list->data;
+						if (d->type == TYPE_RECV && d->dccstat != STAT_ABORTED &&
+							 d->dccstat != STAT_DONE && d->dccstat != STAT_FAILED)
+						{
+							if (d != dcc && strcmp (d->destfile, dcc->destfile) == 0)
+								goto dontresume;
+						}
+						list = list->next;
+					}
 					dcc_resume (dcc);
 				} else
 				{
+dontresume:
 					dcc->resumable = 0;
 					dcc->pos = 0;
 					dcc_connect (dcc);
