@@ -180,7 +180,7 @@ private_msg (struct server *serv, char *tbuf, char *from, char *ip,
 static int
 SearchNick (char *text, char *nicks)
 {
-	char S[NICKLEN];
+	char S[300];	/* size of bluestring in xchatprefs */
 	char *n;
 	char *p;
 	char *t;
@@ -191,7 +191,7 @@ SearchNick (char *text, char *nicks)
 
 	text = strip_color (text);
 
-	safe_strcpy (S, nicks, NICKLEN);
+	safe_strcpy (S, nicks, sizeof (S));
 	n = strtok (S, ",");
 	while (n != NULL)
 	{
@@ -1016,6 +1016,12 @@ process_numeric (server * serv, session * sess, char *outbuf, int n,
 		set_server_name (serv, word_eol[1]);
 		if (sess->type == SESS_SERVER && prefs.logging)
 			setup_logging (sess);
+		/* reset our away status */
+		if (serv->reconnect_away)
+		{
+			handle_command ("/away", serv->front_session, FALSE, FALSE);
+			serv->reconnect_away = FALSE;
+		}
 		goto def;
 	case 4:	/* check the ircd type */
 		serv->is_newtype = FALSE;
@@ -1273,6 +1279,12 @@ process_numeric (server * serv, session * sess, char *outbuf, int n,
 				tcp_send (serv, outbuf);
 			}
 			set_default_modes (serv, outbuf);
+			if (serv->eom_cmd)
+			{
+				handle_command (serv->eom_cmd, sess, FALSE, FALSE);
+				free (serv->eom_cmd);
+				serv->eom_cmd = NULL;
+			}
 			check_willjoin_channels (serv, outbuf);
 			if (serv->supports_watch)
 				notify_send_watches (serv);
