@@ -326,7 +326,16 @@ handle_single_mode (server * serv, char *outbuf, char sign, char mode,
 
  genmode:
 	if (!quiet)
-		EMIT_SIGNAL (XP_TE_CHANMODEGEN, sess, nick, outbuf, outbuf + 2, chan, 0);
+	{
+		if (*arg)
+		{
+			char *buf = malloc (strlen (chan) + strlen (arg) + 2);
+			sprintf (buf, "%s %s", chan, arg);
+			EMIT_SIGNAL (XP_TE_CHANMODEGEN, sess, nick, outbuf, outbuf + 2, buf, 0);
+			free (buf);
+		} else
+			EMIT_SIGNAL (XP_TE_CHANMODEGEN, sess, nick, outbuf, outbuf + 2, chan, 0);
+	}
 }
 
 /* does this mode have an arg? like +b +l +o */
@@ -382,7 +391,10 @@ handle_mode (server * serv, char *outbuf, char *word[], char *word_eol[],
 	char sign;
 	int len;
 	int arg;
+	int i, num_args;
+	int num_modes;
 	int offset = 3;
+	int all_modes_have_args = FALSE;
 
 	/* numeric 324 has everything 1 word later (as opposed to MODE) */
 	if (numeric_324)
@@ -393,6 +405,9 @@ handle_mode (server * serv, char *outbuf, char *word[], char *word_eol[],
 	if (*modes == ':')
 		modes++;
 
+	if (*modes == 0)
+		return;	/* beyondirc's blank modes */
+
 	sess = find_session_from_channel (chan, serv);
 	if (!sess)
 		sess = serv->front_session;
@@ -415,6 +430,30 @@ handle_mode (server * serv, char *outbuf, char *word[], char *word_eol[],
 	modes++;
 	arg = 1;
 
+	/* count the number of arguments (e.g. after the -o+v) */
+	num_args = 0;
+	i = 1;
+	while (i < PDIWORDS)
+	{
+		i++;
+		if (!(*word[i + offset]))
+			break;
+		num_args++;
+	}
+
+	/* count the number of modes (without the -/+ chars */
+	num_modes = 0;
+	i = 0;
+	while (i < strlen (modes))
+	{
+		if (modes[i] != '+' && modes[i] != '-')
+			num_modes++;
+		i++;
+	}
+
+	if (num_args == num_modes)
+		all_modes_have_args = TRUE;
+
 	while (1)
 	{
 		switch (*modes)
@@ -427,7 +466,7 @@ handle_mode (server * serv, char *outbuf, char *word[], char *word_eol[],
 			break;
 		default:
 			argstr = "";
-			if (mode_has_arg (serv, sign, *modes))
+			if (all_modes_have_args || mode_has_arg (serv, sign, *modes))
 			{
 				arg++;
 				argstr = word[arg + offset];
