@@ -446,10 +446,6 @@ static int cmd_servchan (struct session *sess, char *tbuf, char *word[],
 								 char *word_eol[]);
 static int cmd_server (struct session *sess, char *tbuf, char *word[],
 							  char *word_eol[]);
-#ifdef USE_OPENSSL
-static int cmd_sslserver (struct session *sess, char *tbuf, char *word[],
-								  char *word_eol[]);
-#endif
 static int cmd_timer (struct session *sess, char *tbuf, char *word[],
 							 char *word_eol[]);
 static int cmd_topic (struct session *sess, char *tbuf, char *word[],
@@ -602,7 +598,7 @@ struct commands xc_cmds[] = {
 	 N_("/QUOTE <text>, sends the text in raw form to the server\n")},
 #ifdef USE_OPENSSL
 	{"RECONNECT", cmd_reconnect, 0, 0,
-	 N_("/RECONNECT [<host>] [<port>] [<password>] [<ssl>] [<accept_invalid_cert>], Can be called just as /RECONNECT to reconnect to the current server or with /RECONNECT ALL to reconnect to all the open servers\n")}, 
+	 N_("/RECONNECT [-ssl] [<host>] [<port>] [<password>], Can be called just as /RECONNECT to reconnect to the current server or with /RECONNECT ALL to reconnect to all the open servers\n")}, 
 #else 
         {"RECONNECT", cmd_reconnect, 0, 0,
 	N_("/RECONNECT [<host>] [<port>] [<password>], Can be called just as /RECONNECT to reconnect to the current server or with /RECONNECT ALL to reconnect to all the open servers\n")},
@@ -621,21 +617,17 @@ struct commands xc_cmds[] = {
 	{"SETTAB", cmd_settab, 0, 0, ""},
 #ifdef USE_OPENSSL
 	{"SERVCHAN", cmd_servchan, 0, 0,
-	 N_("/SERVCHAN <host> <port> <channel> [<ssl>] [<accept_invalid_cert>], connects and joins a channel\n")},
+	 N_("/SERVCHAN [-ssl] <host> <port> <channel>, connects and joins a channel\n")},
 #else
 	{"SERVCHAN", cmd_servchan, 0, 0,
 	 N_("/SERVCHAN <host> <port> <channel>, connects and joins a channel\n")},
 #endif
 #ifdef USE_OPENSSL
 	{"SERVER", cmd_server, 0, 0,
-	 N_("/SERVER <host> [<port>] [<password>] [<ssl>] [<accept_invalid_cert>], connects to a server, the default port is 6667\n")},
+	 N_("/SERVER [-ssl] <host> [<port>] [<password>], connects to a server, the default port is 6667 for normal connections, and 994 for ssl connections.\n")},
 #else
 	{"SERVER", cmd_server, 0, 0,
-	 N_("/SERVER <host> [<port>] [<password>], connects to a server, the default port is 6667\n")},
-#endif
-#ifdef USE_OPENSSL
-	{"SSLSERVER", cmd_sslserver, 0, 0,
-	 N_("/SSLSERVER <host> [<port>] [<accept_invalid_cert (y/n)>] [<password>], connects to a server, the default port is 994\n")},
+	 N_("/SERVER <host> [<port>] [<password>], connects to a server, the default port is 6667.\n")},
 #endif
 	{"TIMER", cmd_timer, 0, 0, N_("/TIMER <seconds> <command>\n")},
 	{"TOPIC", cmd_topic, 1, 1,
@@ -790,8 +782,15 @@ cmd_addbutton (struct session *sess, char *tbuf, char *word[],
 {
 	if (*word[2] && *word_eol[3])
 	{
-		list_addentry (&button_list, word_eol[3], word[2]);
-		fe_buttons_update (sess);
+		if (sess->type == SESS_DIALOG)
+		{
+			list_addentry (&dlgbutton_list, word_eol[3], word[2]);
+			fe_dlgbuttons_update (sess);
+		} else
+		{
+			list_addentry (&button_list, word_eol[3], word[2]);
+			fe_buttons_update (sess);
+		}
 		return TRUE;
 	}
 	return FALSE;
@@ -885,7 +884,8 @@ cmd_away (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		{
 			/* am I the right server and not a dialog box */
 			if (((struct session *) list->data)->server == sess->server
-				 && ((struct session *) list->data)->type == SESS_CHANNEL)
+				 && ((struct session *) list->data)->type == SESS_CHANNEL
+				 && ((struct session *) list->data)->channel[0])
 			{
 				handle_command (tbuf, (struct session *) list->data,
 									 FALSE, FALSE);
@@ -1315,8 +1315,15 @@ cmd_delbutton (struct session *sess, char *tbuf, char *word[],
 {
 	if (*word[2])
 	{
-		if (list_delentry (&button_list, word[2]))
-			fe_buttons_update (sess);
+		if (sess->type == SESS_DIALOG)
+		{
+			if (list_delentry (&dlgbutton_list, word[2]))
+				fe_dlgbuttons_update (sess);
+		} else
+		{
+			if (list_delentry (&button_list, word[2]))
+				fe_buttons_update (sess);
+		}
 		return TRUE;
 	}
 	return FALSE;
@@ -2240,10 +2247,34 @@ cmd_list (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 int
 cmd_load (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-#ifdef USE_PERL
+	FILE *fp;
+	char *nl;
 	char *file;
+#ifdef USE_PERL
 	int i;
+#endif
 
+	if (strcmp (word[2], "-e") == 0)
+	{
+		file = expand_homedir (word[3]);
+		fp = fopen (file, "r");
+		free (file);
+		if (fp)
+		{
+			tbuf[1024] = 0;
+			while (fgets (tbuf, 1024, fp))
+			{
+				nl = strchr (tbuf, '\n');
+				if (nl)
+					*nl = 0;
+				handle_command (tbuf, sess, FALSE, FALSE);
+			}
+			fclose (fp);
+		}
+		return TRUE;
+	}
+
+#ifdef USE_PERL
 	file = expand_homedir (word[2]);
 	i = perl_load_file (file);
 	free (file);
@@ -2547,10 +2578,6 @@ cmd_reconnect (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	int tmp = prefs.recon_delay;
 	GSList *list;
 	server *serv;
-#ifdef USE_OPENSSL
-	char *use_ssl = word[5];
-	char *accept_invalid_cert = word[6];
-#endif
 
 	prefs.recon_delay = 0;
 
@@ -2569,20 +2596,24 @@ cmd_reconnect (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	there it *should* be a server they are trying to connect to*/
 	else if (*word[2])
 	{
-		if (*word[4])
-			safe_strcpy (sess->server->password, word[4], sizeof (sess->server->password));
-		if (*word[3])
-			sess->server->port = atoi (word[3]);       
-		safe_strcpy (sess->server->hostname, word[2], sizeof (sess->server->hostname));
+		int offset = 0;
 #ifdef USE_OPENSSL
-		if (*word[5] && *word[6])
+		int use_ssl = FALSE;
+
+		if (strcmp (word[2], "-ssl") == 0)
 		{
-			use_ssl = word[5];
-			accept_invalid_cert = word[6];
-			sess->server->use_ssl = *use_ssl ? TRUE : FALSE;
-			sess->server->accept_invalid_cert = *accept_invalid_cert ? TRUE : FALSE;
+			use_ssl = TRUE;
+			offset++;	/* args move up by 1 word */
 		}
+		sess->server->use_ssl = use_ssl;
+		sess->server->accept_invalid_cert = TRUE;
 #endif
+
+		if (*word[4+offset])
+			safe_strcpy (sess->server->password, word[4+offset], sizeof (sess->server->password));
+		if (*word[3+offset])
+			sess->server->port = atoi (word[3+offset]);
+		safe_strcpy (sess->server->hostname, word[2+offset], sizeof (sess->server->hostname));
 		auto_reconnect (sess->server, TRUE, -1);
 	}
 	else
@@ -2638,115 +2669,112 @@ cmd_settab (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 int
 cmd_server (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	char *server = word[2];
-	char *port = word[3];
-	char *pass = word[4];
-#ifdef USE_OPENSSL
-	char *use_ssl = word[5];
-	char *accept_invalid_cert = word[6];
-#endif
+	int offset = 0;
+	char *server;
+	char *port;
+	char *pass;
 	char *co;
+#ifdef USE_OPENSSL
+	int use_ssl = FALSE;
 
-	if (*server)
+	if (strcmp (word[2], "-ssl") == 0)
 	{
-		if (strncasecmp ("irc://", server, 6) == 0)
-		{
-			server += 6;
-			co = strchr (server, ':');
-			if (co)
-			{
-				port = co + 1;
-				*co = 0;
-				pass = word[3];
-#ifdef USE_OPENSSL
-				use_ssl = word[4];
-				accept_invalid_cert = word[5];
-#endif
-			}
-		}
-		sess->willjoinchannel[0] = 0;
-		if (pass)
-			strcpy (sess->server->password, pass);
-#ifdef USE_OPENSSL
-		sess->server->use_ssl = *use_ssl ? TRUE : FALSE;
-		sess->server->accept_invalid_cert = *accept_invalid_cert ? TRUE : FALSE;
-#endif
-		if (*port)
-			connect_server (sess, server, atoi (port), FALSE);
-		else
-			connect_server (sess, server, 6667, FALSE);
-		return TRUE;
+		use_ssl = TRUE;
+		offset++;	/* args move up by 1 word */
 	}
-	return FALSE;
-}
+#endif
+
+	server = word[2 + offset];
+	port = word[3 + offset];
+	pass = word[4 + offset];
+
+	if (!(*server))
+		return FALSE;
 
 #ifdef USE_OPENSSL
-int
-cmd_sslserver (struct session *sess, char *tbuf, char *word[],
-					char *word_eol[])
-{
-	char *server = word[2];
-	char *port = word[3];
-	char *accept_invalid_cert = word[4];
-	char *pass = word[5];
-	char *co;
-
-	if (*server)
+	if (strncasecmp ("ircs://", server, 7) == 0)
 	{
-		if (strncasecmp ("ircs://", server, 7) == 0)
+		use_ssl = TRUE;
+		server += 7;
+		goto urlserv;
+	}
+#endif
+
+	/* dont clear it for /servchan */
+	if (strncasecmp (word[1], "SERVCHAN ", 9))
+		sess->willjoinchannel[0] = 0;
+
+	if (strncasecmp ("irc://", server, 6) == 0)
+	{
+		server += 6;
+#ifdef USE_OPENSSL
+urlserv:
+#endif
+		/* check for port */
+		co = strchr (server, ':');
+		if (co)
 		{
-			server += 7;
-			co = strchr (server, ':');
-			if (co)
+			port = co + 1;
+			*co = 0;
+			pass = word[3 + offset];
+		} else
+			co = server;
+		/* check for channel - mirc style */
+		co = strchr (co + 1, '/');
+		if (co)
+		{
+			*co = 0;
+			co++;
+			if (*co == '#')
 			{
-				port = co + 1;
-				*co = 0;
-				accept_invalid_cert = word[3];
-				pass = word[4];
+				safe_strcpy (sess->willjoinchannel, co, CHANLEN);
+			} else
+			{
+				sess->willjoinchannel[0] = '#';
+				strncpy (sess->willjoinchannel + 1, co, CHANLEN);
+				sess->willjoinchannel[CHANLEN-1] = 0;
 			}
 		}
-		sess->willjoinchannel[0] = 0;
-		sess->server->use_ssl = TRUE;
-		sess->server->accept_invalid_cert =
-			strcmp (accept_invalid_cert, "y") ? FALSE : TRUE;
-		if (pass)
-			strcpy (sess->server->password, pass);
-		if (*port)
-			connect_server (sess, server, atoi (port), FALSE);
-		else
+	}
+
+	if (*pass)
+		strcpy (sess->server->password, pass);
+#ifdef USE_OPENSSL
+	sess->server->use_ssl = use_ssl;
+	sess->server->accept_invalid_cert = TRUE;
+#endif
+
+	if (*port)
+	{
+		connect_server (sess, server, atoi (port), FALSE);
+	} else {
+#ifdef USE_OPENSSL
+		if (use_ssl)
 			connect_server (sess, server, 994, FALSE);
-		return TRUE;
-	}
-	return FALSE;
-}
+		else
 #endif
+			connect_server (sess, server, 6667, FALSE);
+	}
+	return TRUE;
+}
 
 int
 cmd_servchan (struct session *sess, char *tbuf, char *word[],
 				  char *word_eol[])
 {
-	char *server = word[2];
-	char *port = word[3];
-	char *chan = word[4];
+	int offset = 0;
+
 #ifdef USE_OPENSSL
-	char *use_ssl = word[5];
-	char *accept_invalid_cert = word[6];
+	if (strcmp (word[2], "-ssl") == 0)
+		offset++;
 #endif
 
-	if (*server)
+	if (*word[4 + offset])
 	{
-		if (*port)
-		{
-			strcpy (sess->willjoinchannel, chan);
-#ifdef USE_OPENSSL
-			sess->server->use_ssl = *use_ssl ? TRUE : FALSE;
-			sess->server->accept_invalid_cert =
-				*accept_invalid_cert ? TRUE : FALSE;
-#endif
-			connect_server (sess, server, atoi (port), FALSE);
-			return TRUE;
-		}
+		strcpy (sess->willjoinchannel, word[4 + offset]);
+		return cmd_server (sess, tbuf, word, word_eol);
 	}
+
 	return FALSE;
 }
 
@@ -3252,7 +3280,7 @@ handle_command (char *cmd, session *sess, int history, int nocommand)
 				break;
 			}
 	}
-	
+
 	if (!nocommand && cmd[0] == prefs.cmdchar[0] && cmd[1] == prefs.cmdchar[0])
 	{
 		nocommand = TRUE;
