@@ -117,15 +117,23 @@ static XS (XS_IRC_get_prefs);
 static XS (XS_IRC_user_list_short);
 static XS (XS_IRC_perl_script_list);
 
+#ifdef OLD_PERL
+extern void boot_DynaLoader _((CV * cv));
+#else
 extern void boot_DynaLoader (pTHX_ CV* cv);
+#endif
 
 /* xs_init is the second argument perl_pars. As the name hints, it
    initializes XS subroutines (see the perlembed manpage) */
 static void
+#ifdef OLD_PERL
+xs_init ()
+#else
 xs_init (pTHX)
+#endif
 {
 	char *file = __FILE__;
-	
+
 	/* This one allows dynamic loading of perl modules in perl
 	   scripts by the 'use perlmod;' construction*/
 	newXS ("DynaLoader::boot_DynaLoader", boot_DynaLoader, file);
@@ -296,22 +304,22 @@ perl_init (void)
 	     We also redefine the $SIG{__WARN__} handler to have XChat
 	     printing warnings in the main window. (TheHobbit)*/
 	  "sub load_file{"
-	    "my $file_name=shift;"
+	    "my $f_name=shift;"
 	    "local $/=undef;"
-	    "open FH,$file_name or return \"__FAILED__\";"
+	    "open FH,$f_name or return \"__FAILED__\";"
 	    "$_=<FH>;"
 	    "close FH;"
 	    "return $_;"
 	  "}"
 	  "sub load_n_eval{"
-	    "my $file_name=shift;"
-	    "my $strin=load_file($file_name);"
+	    "my $f_name=shift;"
+	    "my $strin=load_file($f_name);"
 	    "return 2 if($strin eq \"__FAILED__\");"
 	    "eval $strin;"
 	    "if($@){"
 	    /*"  #something went wrong\n"*/
-	      "IRC::print \"Errors loading file $file_name:\\n\";"
-	      "IRC::print \"$@\\n\";"
+	      "IRC::print\"Errors loading file $f_name:\\n\";"
+	      "IRC::print\"$@\\n\";"
 	      "return 1;"
 	    "}"
 	    "return 0;"
