@@ -135,12 +135,6 @@ server_connected (server * serv)
 
 	set_nonblocking (serv->sok);
 	set_server_name (serv, serv->servername);
-
-	if (serv->reconnect_away)
-	{
-		handle_command ("/away", serv->front_session, FALSE, FALSE);
-		serv->reconnect_away = FALSE;
-	}
 }
 
 #ifdef USE_OPENSSL
