@@ -153,12 +153,14 @@ PrintText (struct session *sess, unsigned char *text)
 	if (sess->logfd != -1 && prefs.logging)
 	{
 		time_t timval = time (0);
-		char *tim = ctime (&timval) + 11;
 		char *temp = strip_color (text);
+		char *tim = malloc (32);
+		strftime (tim, 32, prefs.timestamp_log_format, localtime (&timval));
 		if (prefs.timestamp || prefs.timestamp_logs)
-			write (sess->logfd, tim, 9);
+			write (sess->logfd, tim, strlen(tim));
 		write (sess->logfd, temp, strlen (temp));
 		free (temp);
+		free (tim);
 	}
 
 #ifdef USE_HEBREW
@@ -218,6 +220,7 @@ open_log_file (char *servname, char *channame)
 		{
 			if (*dir == '|')
 				*dir = '_';
+			dir++;
 		}
 #endif
 	}
