@@ -57,6 +57,7 @@
 
 GSList *popup_list = 0;
 GSList *button_list = 0;
+GSList *dlgbutton_list = 0;
 GSList *command_list = 0;
 GSList *ctcp_list = 0;
 GSList *replace_list = 0;
@@ -68,6 +69,7 @@ GSList *usermenu_list = 0;
 GSList *urlhandler_list = 0;
 static GSList *away_list = 0;
 
+static int in_xchat_exit = FALSE;
 int xchat_is_quitting = FALSE;
 int auto_connect = TRUE;
 
@@ -141,7 +143,7 @@ tcp_send_real (struct server *serv, char *buf, int len)
 static int
 tcp_send_queue (struct server *serv)
 {
-	char *buf, *p;
+	char *buf, *p, pri;
 	int len, i;
 	GSList *list;
 	time_t now = time (0);
@@ -150,29 +152,42 @@ tcp_send_queue (struct server *serv)
 	if (!is_server (serv))
 		return 0;
 
-	list = serv->outbound_queue;
-
-	while (list)
+	/* first try priority 1 entries */
+	pri = 1;
+	while (pri >= 0)
 	{
-		buf = (char *) list->data;
-		len = strlen (buf);
-
-		if (serv->next_send < now)
-			serv->next_send = now;
-		if (serv->next_send - now >= 10)
-			return 1;				  /* don't remove the timeout handler */
-
-		for (p = buf, i = len; i && *p != ' '; p++, i--);
-			serv->next_send += (2 + i / 120);
-		serv->sendq_len -= len;
-		fe_set_throttle (serv);
-
-		tcp_send_real (serv, buf, len);
-
-		serv->outbound_queue = g_slist_remove (serv->outbound_queue, buf);
-		free (buf);
-
 		list = serv->outbound_queue;
+		while (list)
+		{
+			buf = (char *) list->data;
+			if (buf[0] == pri)
+			{
+				buf++;	/* skip the priority byte */
+				len = strlen (buf);
+
+				if (serv->next_send < now)
+					serv->next_send = now;
+				if (serv->next_send - now >= 10)
+					return 1;				  /* don't remove the timeout handler */
+
+				for (p = buf, i = len; i && *p != ' '; p++, i--);
+				serv->next_send += (2 + i / 120);
+				serv->sendq_len -= len;
+				fe_set_throttle (serv);
+
+				tcp_send_real (serv, buf, len);
+
+				buf--;
+				serv->outbound_queue = g_slist_remove (serv->outbound_queue, buf);
+				free (buf);
+				list = serv->outbound_queue;
+			} else
+			{
+				list = list->next;
+			}
+		}
+		/* now try pri 0 */
+		pri--;
 	}
 	return 0;						  /* remove the timeout handler */
 }
@@ -212,16 +227,23 @@ tcp_send_len (struct server *serv, char *buf, int len)
 #endif    
 
 	if (!prefs.throttle)
-  		return tcp_send_real (serv, buf, len);
+		return tcp_send_real (serv, buf, len);
 
-    dbuf = malloc (len + 1);
-    memcpy (dbuf, buf, len);
-    dbuf[len] = 0;
-    serv->outbound_queue = g_slist_append (serv->outbound_queue, dbuf);
-    serv->sendq_len += strlen (dbuf); /* tcp_send_queue uses strlen */
-        
-    if (tcp_send_queue (serv) && noqueue)
-        fe_timeout_add (500, tcp_send_queue, serv);
+	dbuf = malloc (len + 2);	/* first byte is the priority */
+	dbuf[0] = 1;	/* pri 1 for most things */
+	memcpy (dbuf + 1, buf, len);
+	dbuf[len + 1] = 0;
+
+	/* privmsg and notice get a lower priority */
+	if (strncasecmp (dbuf + 1, "PRIVMSG", 7) == 0 ||
+		 strncasecmp (dbuf + 1, "NOTICE", 6) == 0)
+		dbuf[0] = 0;
+
+	serv->outbound_queue = g_slist_append (serv->outbound_queue, dbuf);
+	serv->sendq_len += len; /* tcp_send_queue uses strlen */
+
+	if (tcp_send_queue (serv) && noqueue)
+		fe_timeout_add (500, tcp_send_queue, serv);
     
 	return 1;
 }
@@ -593,6 +615,8 @@ kill_server_callback (server * serv)
 		free (serv->bad_nick_prefixes);
 	if (serv->last_away_reason)
 		free (serv->last_away_reason);
+	if (serv->eom_cmd)
+		free (serv->eom_cmd);
 	free (serv->gui);
 	free (serv);
 
@@ -721,7 +745,7 @@ kill_session_callback (session * killsess)
 	free (killsess->current_modes);
 	free (killsess);
 
-	if (!sess_list)
+	if (!sess_list && !in_xchat_exit)
 		xchat_exit ();						/* sess_list is empty, quit! */
 
 	list = sess_list;
@@ -866,7 +890,7 @@ save_away_message (struct server *serv, char *nick, char *msg)
 	"NAME UserHost\n"			"CMD /quote USERHOST %s\n\n"\
 	"NAME ENDSUB\n"			"CMD \n\n"\
 	"NAME SUB\n"				"CMD External\n\n"\
-	"NAME Traceroute\n"		"CMD !rxvt -e /bin/sh -c \"traceroute %h ; sleep 30\"\n\n"\
+	"NAME Traceroute\n"		"CMD !rxvt -e /bin/sh -c \"/usr/sbin/traceroute %h ; sleep 30\"\n\n"\
 	"NAME Ping\n"				"CMD !rxvt -e /bin/sh -c \"ping -c 4 %h ; sleep 30\"\n\n"\
 	"NAME Telnet\n"			"CMD !rxvt -e telnet %h\n\n"\
 	"NAME ENDSUB\n"			"CMD \n\n"\
@@ -880,6 +904,13 @@ save_away_message (struct server *serv, char *nick, char *msg)
 	"NAME Sendfile\n"			"CMD /dcc send %s\n\n"\
 	"NAME Dialog\n"			"CMD /query %s\n\n"
 
+#define defaultconf_dlgbuttons \
+	"NAME Whois\n"				"CMD /whois %s\n\n"\
+	"NAME Send\n"				"CMD /dcc send %s\n\n"\
+	"NAME Chat\n"				"CMD /dcc chat %s\n\n"\
+	"NAME Ping\n"				"CMD /ping %s\n\n"\
+	"NAME Clear\n"				"CMD /clear\n\n"\
+
 #define defaultconf_replace \
 	"NAME teh\n"				"CMD the\n\n"\
 	"NAME r\n"					"CMD are\n\n"\
@@ -903,6 +934,7 @@ save_away_message (struct server *serv, char *nick, char *msg)
    "NAME RAW\n"			"CMD /quote &2\n\n"\
    "NAME SERVHELP\n"		"CMD /quote HELP\n\n"\
 	"NAME SPING\n"			"CMD /ping\n\n"\
+	"NAME SSLSERVER\n"	"CMD /server -ssl &2\n\n"\
    "NAME SV\n"				"CMD /echo xchat %v %m\n\n"\
    "NAME UMODE\n"			"CMD /mode %n &2\n\n"\
    "NAME UPTIME\n"		"CMD /quote STATS u\n\n"\
@@ -1005,6 +1037,7 @@ xchat_init (void)
 	list_loadconf ("popup.conf", &popup_list, defaultconf_popup);
 	list_loadconf ("ctcpreply.conf", &ctcp_list, defaultconf_ctcp);
 	list_loadconf ("buttons.conf", &button_list, defaultconf_buttons);
+	list_loadconf ("dlgbuttons.conf", &dlgbutton_list, defaultconf_dlgbuttons);
 	list_loadconf ("commands.conf", &command_list, defaultconf_commands);
 	list_loadconf ("replace.conf", &replace_list, defaultconf_replace);
 	list_loadconf ("usermenu.conf", &usermenu_list, defaultconf_usermenu);
@@ -1033,6 +1066,7 @@ void
 xchat_exit (void)
 {
 	xchat_is_quitting = TRUE;
+	in_xchat_exit = TRUE;
 #ifdef USE_PERL
 	perl_end ();
 #endif
