@@ -121,6 +121,7 @@ struct xchatprefs
 	char trans_file[256];
 	char logmask[256];
 	char stamp_format[64];
+	char timestamp_log_format[64];
 
 	char proxy_host[64];
 	int proxy_port;
@@ -159,6 +160,7 @@ struct xchatprefs
 	unsigned long dcc_ip;
 	char dcc_ip_str[16];
 
+	unsigned int mainwindow_save;
 	unsigned int perc_color;
 	unsigned int perc_ascii;
 	unsigned int hilightnick;
@@ -350,6 +352,8 @@ struct server
 	char *nick_modes;					/* e.g. "aohv" */
 	char *bad_nick_prefixes;		/* for ircd that doesn't give the modes */
 
+	char *eom_cmd;						/* end-of-motd command, free it! */
+
 	GSList *outbound_queue;
 	int next_send;						/* cptr->since in ircu */
 	int sendq_len;						/* queue size */
