@@ -340,7 +340,7 @@ key_load_defaults ()
 		"C\nb\nInsert in Buffer\nD1:%B\nD2!\n\n"
 		"C\nk\nInsert in Buffer\nD1:%C\nD2!\n\n"
 		"S\nNext\nChange Selected Nick\nD1!\nD2!\n\n"
-		"S\nPrior\nChange Selected Nick\nD1!\nD2!\n\n"
+		"S\nPrior\nChange Selected Nick\nD1:Up\nD2!\n\n"
 		"None\nNext\nScroll Page\nD1!\nD2!\n\n"
 		"None\nPrior\nScroll Page\nD1:Up\nD2!\n\n"
 		"None\nDown\nNext Command\nD1!\nD2!\n\n"
@@ -1247,15 +1247,12 @@ key_action_tab_comp (GtkWidget * wid, GdkEventKey * ent, char *d1, char *d2,
 	{
 		if (tab_nick_comp (wid, 1) == -1)
 			return 1;
-		else
-			return 2;
 	} else
 	{
 		if (tab_nick_comp (wid, 0) == -1)
 			return 1;
-		else
-			return 2;
 	}
+	return 2;
 }
 
 static int
@@ -1325,6 +1322,9 @@ replace_handle (GtkWidget *t)
 	text = gtk_entry_get_text (GTK_ENTRY (t));
 
 	len = strlen (text);
+	if (len < 1)
+		return;
+
 	for (c = len - 1; c > 0; c--)
 	{
 		if (text[c] == ' ')
@@ -1611,10 +1611,11 @@ tab_comp_cmd (GtkWidget * t)
 
 /* In the following 'b4' is *before* the text (just say b4 and before out loud)
    and c5 is *after* (because c5 is next after b4, get it??) --AGL */
+/* pos is the current cursor position of the inputgad --GeEkMaN */
 
 static int
 tab_nick_comp_next (struct session *sess, GtkWidget * wid, char *b4,
-						  char *nick, char *c5, int shift)
+						  char *nick, char *c5, int shift, int pos)
 {
 	struct User *user = 0, *last = NULL;
 	char buf[4096];
@@ -1651,7 +1652,9 @@ tab_nick_comp_next (struct session *sess, GtkWidget * wid, char *b4,
 				snprintf (buf, 4096, "%s %s%s", b4, nick, c5);
 		}
 	}
+	pos = strlen(buf) - strlen(c5);
 	gtk_entry_set_text (GTK_ENTRY (wid), buf);
+	GTK_EDITABLE (wid)->current_pos = pos;
 
 	return 1;
 }
@@ -1702,7 +1705,7 @@ tab_nick_comp (GtkWidget *t, int shift)
 
 			if ((!space || space == &text[len - 1]) &&
 				 text[len - (space ? 2 : 1)] == prefs.nick_suffix[0])
-	{
+			{
 				/* This causes the nickname to cycle. */
 				nick_comp_chng(t, shift);
 				return 0;
@@ -1733,7 +1736,7 @@ tab_nick_comp (GtkWidget *t, int shift)
 		memmove (text, &text[i + 1], (j - i) + 1);
 		text[(j - i) - 1] = 0;
 
-		if (tab_nick_comp_next (sess, t, b4, text, c5, shift))
+		if (tab_nick_comp_next (sess, t, b4, text, c5, shift, j))
 		{
 			free (b4);
 			free (c5);
@@ -1833,31 +1836,36 @@ tab_nick_comp (GtkWidget *t, int shift)
 		}
 		PrintText (sess, nick_buf);
 
-		if (first)
+		if (first) {
 			snprintf (buf, sizeof (buf), "%s", match_text);
+			j = strlen(buf);
+		}
 		else
 		{
 			snprintf (buf, sizeof (buf), "%s %s%s", b4, match_text, c5);
-			GTK_EDITABLE (t)->current_pos = strlen (b4) + strlen (match_text);
+			j = strlen (buf) - strlen (c5);
 			free (b4);
 			free (c5);
 		}
 		free (match_text);
 	} else
 	{
-		if (first)
+		if (first) {
 			snprintf (buf, sizeof (buf), "%s%c ", match_user->nick,
 						 prefs.nick_suffix[0]);
+			j = strlen (buf);
+		}
 		else
 		{
 			snprintf (buf, sizeof (buf), "%s %s%s", b4, match_user->nick, c5);
-			GTK_EDITABLE (t)->current_pos =
-				strlen (b4) + strlen (match_user->nick);
+			j = strlen (buf) - strlen (c5);
 			free (b4);
 			free (c5);
 		}
 	}
 	gtk_entry_set_text (GTK_ENTRY (t), buf);
+	/* GeEkMaN: Restore the last cursor position (j is used only for this) */
+	GTK_EDITABLE (t)->current_pos = j;
 
 	return 0;
 }
