@@ -777,7 +777,18 @@ void
 maingui_configure (session *sess)
 {
 	if (sess == 0)			/* for the main_window */
+	{
 		sess = menu_sess;
+		if (main_window && prefs.mainwindow_save)
+		{
+			gdk_window_get_root_origin (main_window->window,
+										  &prefs.mainwindow_left,
+										  &prefs.mainwindow_top);
+			gdk_window_get_size (main_window->window,
+										&prefs.mainwindow_width,
+										&prefs.mainwindow_height);
+		}
+	}
 
 	if (sess)
 	{
@@ -887,7 +898,7 @@ gui_new_tab_callback (GtkWidget * widget, GtkNotebookPage * nbpage,
 	struct session *sess;
 	GSList *list = sess_list;
 
-	if (xchat_is_quitting)
+	if (xchat_is_quitting || main_window == NULL)
 		return;
 
 	wins_update_notebooktitle (nbpage->child);
