@@ -1126,6 +1126,15 @@ menu_pythonlist (void)
                            "%s  =  selected nick\n"\
 									"%t  =  time/date\n")
 
+#define dlgbutton_help      _("Dialog Buttons - Special codes:\n\n"\
+                           "%a  =  all selected nicks\n"\
+                           "%c  =  current channel\n"\
+                           "%h  =  selected nick's hostname\n"\
+									"%m  =  machine info\n"\
+                           "%n  =  your nick\n"\
+                           "%s  =  selected nick\n"\
+									"%t  =  time/date\n")
+
 #define ctcp_help          _("CTCP Replies - Special codes:\n\n"\
                            "%d  =  data (the whole ctcp)\n"\
 									"%m  =  machine info\n"\
@@ -1196,6 +1205,13 @@ menu_ulbuttons (void)
 							 "buttons.conf", ulbutton_help);
 }
 
+static void
+menu_dlgbuttons (void)
+{
+	editlist_gui_open (dlgbutton_list, _("X-Chat: Dialog buttons"), "dlgbuttons",
+							 "dlgbuttons.conf", dlgbutton_help);
+}
+
 static void
 menu_ctcpguiopen (void)
 {
@@ -1502,6 +1518,12 @@ static GnomeUIInfo settingsmenu[] = {
 	 menu_ulpopup, 0, 0,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_INDEX,
 	 0, 0, 0},
+	{
+	 GNOME_APP_UI_ITEM,
+	 N_("Dialog Buttons.."), 0,
+	 menu_dlgbuttons, 0, 0,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_STOP,
+	 0, 0, 0},
 	{
 	 GNOME_APP_UI_ITEM,
 	 N_("Replace Popup.."), 0,
@@ -1678,7 +1700,7 @@ createmenus (void *app, struct session *sess, int bar)
 	((GtkCheckMenuItem *) (usermodesmenu[10].widget))->active = prefs.autodialog;
 	((GtkCheckMenuItem *) (usermodesmenu[11].widget))->active = prefs.autodccchat;
 	((GtkCheckMenuItem *) (usermodesmenu[12].widget))->active = prefs.autodccsend;
-	((GtkCheckMenuItem *) (settingsmenu[14].widget))->active = prefs.autosave;
+	((GtkCheckMenuItem *) (settingsmenu[15].widget))->active = prefs.autosave;
 
 #ifndef USE_PERL
 	gtk_widget_set_sensitive (loadmenu[0].widget, FALSE);
@@ -1770,16 +1792,17 @@ static struct mymenu mymenu[] = {
 	{M_MENU, N_("CTCP Replies.."), (menucallback) menu_ctcpguiopen, 0, 1},
 	{M_MENU, N_("Userlist Buttons.."), (menucallback) menu_ulbuttons, 0, 1},
 	{M_MENU, N_("Userlist Popup.."), (menucallback) menu_ulpopup, 0, 1},
+	{M_MENU, N_("Dialog Buttons.."), (menucallback) menu_dlgbuttons, 0, 1},
 	{M_MENU, N_("Replace.."), (menucallback) menu_rpopup, 0, 1},
 	{M_MENU, N_("URL Handlers.."), (menucallback) menu_urlhandlers, 0, 1},
-	{M_MENU, N_("Edit Event Texts.."), (menucallback) menu_evtpopup, 0, 1},	/* 50 */
+	{M_MENU, N_("Edit Event Texts.."), (menucallback) menu_evtpopup, 0, 1},	/* 51 */
 	{M_MENU, N_("Edit Key Bindings.."), (menucallback) menu_keypopup, 0, 1},
 	{M_SEP, 0, 0, 0, 0},
 	{M_MENU, N_("Reload Settings"), (menucallback) menu_reload, 0, 1},
 	{M_SEP, 0, 0, 0, 0},
 	{M_MENU, N_("Save Settings now"), (menucallback) menu_savedefault, 0, 1},
 	{M_MENUTOG, N_("Save Settings on exit"), (menucallback) menu_saveexit, 1, 1},
-	{M_NEWMENU, N_("Scripts & Plugins"), 0, 0, 1},	/* 57 */
+	{M_NEWMENU, N_("Scripts & Plugins"), 0, 0, 1},	/* 58 */
 #ifdef USE_PERL
 	{M_MENU, N_("Load Perl Script.."), (menucallback) menu_loadperl, 0, 1},
 	{M_MENU, N_("Unload All Scripts"), (menucallback) menu_unloadall, 0, 1},
@@ -1850,7 +1873,7 @@ createmenus (void *app, struct session *sess, int bar)
 	mymenu[38-menuoffset].state = prefs.autodialog;
 	mymenu[39-menuoffset].state = prefs.autodccchat;
 	mymenu[40-menuoffset].state = prefs.autodccsend;
-	mymenu[56-menuoffset].state = prefs.autosave;
+	mymenu[57-menuoffset].state = prefs.autosave;
 
 	while (1)
 	{
