@@ -17,9 +17,10 @@
  */
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
-#include "../common/xchat.h"
 #include "fe-gtk.h"
+#include "../common/xchat.h"
 #include "gtkutil.h"
 
 #ifdef USE_GDK_PIXBUF
@@ -32,15 +33,19 @@
 
 #include "../pixmaps/globe.xpm"
 #include "../pixmaps/server.xpm"
+#include "../pixmaps/admin.xpm"
 #include "../pixmaps/op.xpm"
 #include "../pixmaps/hop.xpm"
 #include "../pixmaps/voice.xpm"
+#ifdef USE_XLIB
 #include "../pixmaps/xchat_mini.xpm"
+#endif
 #include "../pixmaps/xchat.xpm"
 
 
 GdkPixmap *pix_globe;
 GdkPixmap *pix_server;
+GdkPixmap *pix_admin;
 GdkPixmap *pix_op;
 GdkPixmap *pix_hop;
 GdkPixmap *pix_voice;
@@ -49,6 +54,7 @@ GdkPixmap *pix_xchat;
 
 GdkBitmap *mask_globe;
 GdkBitmap *mask_server;
+GdkBitmap *mask_admin;
 GdkBitmap *mask_op;
 GdkBitmap *mask_hop;
 GdkBitmap *mask_voice;
@@ -56,6 +62,7 @@ GdkBitmap *mask_xchat_mini;
 GdkBitmap *mask_xchat;
 
 
+
 static void
 pixmap_load_from_data (GdkPixmap **pix, GdkBitmap **mask, char **xpm_data)
 {
@@ -66,8 +73,8 @@ pixmap_load_from_data (GdkPixmap **pix, GdkBitmap **mask, char **xpm_data)
 #endif
 }
 
-GdkPixmap *
-pixmap_load_from_file (char *file)
+static GdkPixmap *
+pixmap_load_from_file_real (char *file)
 {
 #ifdef USE_GDK_PIXBUF
 	GdkPixbuf *img;
@@ -92,7 +99,7 @@ pixmap_load_from_file (char *file)
 }
 
 GdkPixmap *
-pixmap_load_from_file_with_msg (char *filename)
+pixmap_load_from_file (char *filename)
 {
 	char buf[256];
 	GdkPixmap *pix;
@@ -100,7 +107,7 @@ pixmap_load_from_file_with_msg (char *filename)
 	if (filename[0] == '\0')
 		return NULL;
 
-	pix = pixmap_load_from_file (filename);
+	pix = pixmap_load_from_file_real (filename);
 	if (pix == NULL)
 	{
 		strcpy (buf, "Cannot open:\n\n");
@@ -116,10 +123,13 @@ pixmaps_init (void)
 {
 	pixmap_load_from_data (&pix_globe,		&mask_globe,		globe_xpm);
 	pixmap_load_from_data (&pix_server,		&mask_server,		server_xpm);
+	pixmap_load_from_data (&pix_admin,		&mask_admin,		admin_xpm);
 	pixmap_load_from_data (&pix_op,			&mask_op,			op_xpm);
 	pixmap_load_from_data (&pix_hop,			&mask_hop,			hop_xpm);	
 	pixmap_load_from_data (&pix_voice,		&mask_voice,		voice_xpm);
 	pixmap_load_from_data (&pix_xchat,		&mask_xchat,		xchat_xpm);
+#ifdef USE_XLIB
 	pixmap_load_from_data (&pix_xchat_mini,&mask_xchat_mini, xchat_mini_xpm);
+#endif
 }
 
