@@ -45,6 +45,7 @@ static GtkWidget *entry_port;
 static GtkWidget *entry_comment;
 static GtkWidget *entry_password;
 static GtkWidget *entry_nick;
+static GtkWidget *entry_eomcmd;
 static GtkWidget *entry_autoconnect;
 static GtkWidget *entry_use_proxy;
 static GtkWidget *entry_use_ssl;
@@ -115,14 +116,10 @@ add_server_entry (struct slentry *serv)
 	if (!strcmp ("SUB", serv->server))
 	{
 		new = malloc (sizeof (struct slentry));
+		memset (new, 0, sizeof (struct slentry));
 		text[0] = new->comment;
 		strcpy (new->comment, serv->comment);
 		strcpy (new->server, serv->server);
-		new->channel[0] = 0;
-		new->password[0] = 0;
-		new->nick[0] = 0;
-		new->flags = 0;
-		new->port = 0;
 		if (serv->port)
 			new->port = 1;
 		node = gtk_ctree_insert_node (GTK_CTREE (sltree), parent,
@@ -152,6 +149,7 @@ add_server_entry (struct slentry *serv)
 		strcpy (new->server, serv->server);
 		strcpy (new->password, serv->password);
 		strcpy (new->nick, serv->nick);
+		strcpy (new->eom_cmd, serv->eom_cmd);
 		text[0] = new->comment;
 		node = gtk_ctree_insert_node (GTK_CTREE (sltree), parent,
 												NULL, text, 4, pix_server, mask_server,
@@ -179,6 +177,7 @@ add_defaults (void)
 
 	serv.password[0] = 0;
 	serv.nick[0] = 0;
+	serv.eom_cmd[0] = 0;
 	while (dserv[i].server != 0)
 	{
 		strcpy (serv.channel, dserv[i].channel);
@@ -223,6 +222,8 @@ read_next_server_entry (char *my_cfg, struct slentry *serv)
 		my_cfg = my_cfg_tmp;
 	if ((my_cfg_tmp = cfg_get_str (my_cfg, "comment", serv->comment)))
 		my_cfg = my_cfg_tmp;
+	if ((my_cfg_tmp = cfg_get_str (my_cfg, "eom_cmd", serv->eom_cmd)))
+		my_cfg = my_cfg_tmp;
 
 	return my_cfg;
 }
@@ -259,6 +260,7 @@ load_serverentrys (int select_row)
 			{
 				serv.nick[0] = 0;
 				serv.flags = 0;
+				serv.eom_cmd[0] = 0;
 				my_cfg = read_next_server_entry (my_cfg, &serv);
 				if (my_cfg)
 					add_server_entry (&serv);
@@ -297,9 +299,10 @@ write_serverentry (struct slentry *entry, int fh)
 				 "channel = %s\n"
 				 "password = %s\n"
 				 "nick = %s\n"
-				 "comment = %s\n\n",
-				 entry->server, entry->port, entry->flags,
-				 entry->channel, entry->password, entry->nick, entry->comment);
+				 "comment = %s\n"
+				 "eom_cmd = %s\n\n",
+				 entry->server, entry->port, entry->flags, entry->channel,
+				 entry->password, entry->nick, entry->comment, entry->eom_cmd);
 	write (fh, buf, strlen (buf));
 }
 
@@ -328,36 +331,20 @@ parse_serverentrys (GtkCTree * ctree, GtkCTreeNode * node, int *fh)
 
 	while (diff < 0)
 	{
-		buf.port = 0;
-		buf.flags = 0;
-		buf.channel[0] = 0;
-		buf.password[0] = 0;
-		buf.nick[0] = 0;
-		buf.comment[0] = 0;
+		memset (&buf, 0, sizeof (struct slentry));
 		strcpy (buf.server, "ENDSUB");
 		write_serverentry (&buf, *fh);
 		diff++;
 	}
 
-	strcpy (buf.channel, temporary->channel);
-	strcpy (buf.server, temporary->server);
-	strcpy (buf.password, temporary->password);
-	strcpy (buf.nick, temporary->nick);
-	strcpy (buf.comment, temporary->comment);
-	buf.port = temporary->port;
-	buf.flags = temporary->flags;
+	memcpy (&buf, temporary, sizeof (struct slentry));
 	write_serverentry (&buf, *fh);
 
 	if (!strcmp (buf.server, "SUB")
 		 && (((GTK_CTREE_ROW (node))->children)) == 0)
 	{
 		/* If we got a group without any children we need an ENDSUB at least */
-		buf.port = 0;
-		buf.flags = 0;
-		buf.channel[0] = 0;
-		buf.password[0] = 0;
-		buf.nick[0] = 0;
-		buf.comment[0] = 0;
+		memset (&buf, 0, sizeof (struct slentry));
 		strcpy (buf.server, "ENDSUB");
 		write_serverentry (&buf, *fh);
 	}
@@ -488,7 +475,10 @@ done_edit_entry (void)
 				  gtk_entry_get_text (GTK_ENTRY (entry_password)));
 		strcpy (editentry->nick,
 				  gtk_entry_get_text (GTK_ENTRY (entry_nick)));
-		editentry->port = atoi (gtk_entry_get_text (GTK_ENTRY (entry_port)));
+		strcpy (editentry->eom_cmd,
+				  gtk_entry_get_text (GTK_ENTRY (entry_eomcmd)));
+		editentry->port = gtk_spin_button_get_value_as_int (
+														(GtkSpinButton *)entry_port);
 
 		if (!gtk_toggle_button_get_active
 			 (GTK_TOGGLE_BUTTON (entry_autoconnect)))
@@ -531,6 +521,28 @@ entry_use_ssl_toggled (GtkWidget * w, gpointer entry_accept_invalid_cert)
 
 #endif
 
+/* creates one entry box for the Edit-Server window */
+
+static GtkWidget *
+table_entry (char *labeltext, GtkWidget *table, int max, char *def,
+				 int row, int col)
+{
+	GtkWidget *entry;
+	GtkWidget *label;
+
+	label = gtk_label_new (labeltext);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, row-1, row, col, col+1);
+	gtk_widget_show (label);
+
+	entry = gtk_entry_new_with_max_length (max);
+	gtk_entry_set_text (GTK_ENTRY (entry), def);
+	gtk_table_attach_defaults (GTK_TABLE (table), entry, row, row+1, col, col+1);
+	gtk_widget_show (entry);
+
+	return entry;
+}
+
+
 /*
  * edit_entry_clicked:
  * called when the users clicks on the "edit" button in the serverlist GUI
@@ -538,8 +550,8 @@ entry_use_ssl_toggled (GtkWidget * w, gpointer entry_accept_invalid_cert)
 static void
 edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 {
-	char portbuffer[16];
-	GtkWidget *vbox, *hbox, *box1, *box2, *frame, *wid1;
+	GtkWidget *label, *tab, *vbox, *hbox, *box1, *frame, *wid1, *pbox;
+	GtkAdjustment *adj;
 
 	if (sleditwin)
 	{
@@ -555,6 +567,7 @@ edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 		return;
 
 	sleditwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	wins_set_icon (sleditwin);
 	gtk_window_set_title (GTK_WINDOW (sleditwin), _("X-Chat: Edit entry"));
 	gtk_signal_connect (GTK_OBJECT (sleditwin), "delete_event",
 							  GTK_SIGNAL_FUNC (close_edit_entry), 0);
@@ -577,53 +590,61 @@ edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 	gtk_widget_show (wid1);
 
 	frame = gtk_frame_new (_("Edit entry:"));
-	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
-	if (!is_group (editnode))
+	gtk_container_add (GTK_CONTAINER (vbox), frame);
+/*	if (!is_group (editnode))
 		gtk_widget_set_usize (frame, 400, 150);
 	else
-		gtk_widget_set_usize (frame, 400, 70);
+		gtk_widget_set_usize (frame, 400, 70);*/
 	gtk_widget_show (frame);
 
 	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_container_border_width (GTK_CONTAINER (hbox), 5);
 	gtk_container_add (GTK_CONTAINER (frame), hbox);
 	gtk_widget_show (hbox);
 
-	box1 = gtk_vbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), box1, FALSE, FALSE, 0);
-	gtk_widget_show (box1);
+	tab = gtk_table_new (6, 2, FALSE);
+	gtk_container_add (GTK_CONTAINER (hbox), tab);
+	gtk_widget_show (tab);
 
-	box2 = gtk_vbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), box2, TRUE, TRUE, 0);
-	gtk_widget_show (box2);
-
-	gtkutil_label_new (_("Name:"), box1);
-	entry_comment = gtkutil_entry_new (99, box2, NULL, NULL);
-	gtk_entry_set_text (GTK_ENTRY (entry_comment), editentry->comment);
+	entry_comment = table_entry (_("Name:"), tab, 99, editentry->comment, 1, 0);
 
 	if (!is_group (editnode))
 	{
-		gtkutil_label_new (_("Server:"), box1);
-		entry_server = gtkutil_entry_new (131, box2, NULL, NULL);
+		label = gtk_label_new (_("Server:"));
+		gtk_table_attach_defaults (GTK_TABLE (tab), label, 0, 1, 1, 2);
+		gtk_widget_show (label);
+
+		pbox = gtk_hbox_new (0, 0);
+		gtk_table_attach_defaults (GTK_TABLE (tab), pbox, 1, 2, 1, 2);
+		gtk_widget_show (pbox);
+
+		entry_server = gtkutil_entry_new (131, pbox, NULL, NULL);
 		gtk_entry_set_text (GTK_ENTRY (entry_server), editentry->server);
 
-		sprintf (portbuffer, "%d", editentry->port);
-		gtkutil_label_new (_("Port:"), box1);
-		entry_port = gtkutil_entry_new (5, box2, NULL, NULL);
-		gtk_entry_set_text (GTK_ENTRY (entry_port), portbuffer);
+		gtkutil_label_new (_("Port:"), pbox);
+		entry_port = gtk_spin_button_new (0, 0, 0);
+		adj = gtk_spin_button_get_adjustment ((GtkSpinButton*)entry_port);
+		adj->lower = 1;
+		adj->upper = 65535;
+		adj->step_increment = 1;
+		gtk_adjustment_changed (adj);
+		gtk_spin_button_set_value ((GtkSpinButton*)entry_port, editentry->port);
+		gtk_widget_set_usize (entry_port, 58, 0);
+		gtk_box_pack_start (GTK_BOX (pbox), entry_port, 0, 0, 0);
+		gtk_widget_show (entry_port);
 
-		gtkutil_label_new (_("Password:"), box1);
-		entry_password = gtkutil_entry_new (85, box2, NULL, NULL);
-		gtk_entry_set_text (GTK_ENTRY (entry_password), editentry->password);
+		entry_password = table_entry (_("Password:"), tab, 85,
+												editentry->password, 1, 2);
 
-		gtkutil_label_new (_("Channels:"), box1);
-		entry_channel = gtkutil_entry_new (201, box2, NULL, NULL);
-		gtk_entry_set_text (GTK_ENTRY (entry_channel), editentry->channel);
-		gtk_widget_show (entry_channel);
+		entry_channel = table_entry (_("Channels:"), tab, CHANLEN,
+											  editentry->channel, 1, 3);
 
-		gtkutil_label_new ("Nickname:", box1);
-		entry_nick = gtkutil_entry_new (201, box2, NULL, NULL);
-		gtk_entry_set_text (GTK_ENTRY (entry_nick), editentry->nick);
-		gtk_widget_show (entry_nick);
+		entry_nick = table_entry (_("Nickname:"), tab, NICKLEN,
+										  editentry->nick, 1, 4);
+
+		entry_eomcmd = table_entry (_("Connect Cmd:"), tab, 71,
+											 editentry->eom_cmd, 1, 5);
+		add_tip (entry_eomcmd, _("Command to execute after the connection is complete"));
 
 		box1 = gtk_hbox_new (FALSE, 0);
 		entry_autoconnect = gtk_check_button_new_with_label (_("Autoconnect"));
@@ -663,22 +684,22 @@ edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 		gtk_box_pack_start (GTK_BOX (box1), entry_use_ssl, TRUE, FALSE, 0);
 		gtk_box_pack_start (GTK_BOX (box1), entry_accept_invalid_cert, TRUE,
 								  FALSE, 0);
-		gtk_box_pack_start (GTK_BOX (vbox), box1, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vbox), box1, FALSE, TRUE, 0);
 		gtk_widget_show (entry_autoconnect);
 		gtk_widget_show (entry_use_proxy);
 		gtk_widget_show (entry_use_ssl);
 		gtk_widget_show (entry_accept_invalid_cert);
 		gtk_widget_show (box1);
 	}
-	box1 = gtk_hbox_new (TRUE, 2);
 
+	box1 = gtk_hbox_new (TRUE, 2);
 	gtkutil_button (slwin, GNOME_STOCK_BUTTON_OK, _("Ok"),
 						 done_edit_entry, 0, box1);
 	gtkutil_button (slwin, GNOME_STOCK_BUTTON_CANCEL, _("Cancel"),
 						 close_edit_entry, 0, box1);
-
-	gtk_box_pack_start (GTK_BOX (vbox), box1, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), box1, FALSE, TRUE, 0);
 	gtk_widget_show (box1);
+
 	gtk_widget_show (sleditwin);
 }
 
@@ -689,7 +710,7 @@ edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 static void
 new_server_clicked (GtkWidget * wid, struct session *sess)
 {
-	struct slentry *new = 0;
+	struct slentry *new;
 	GtkCTreeNode *node;
 	GtkCTreeNode *sibling;
 	GtkCTreeNode *parent = 0;
@@ -699,13 +720,9 @@ new_server_clicked (GtkWidget * wid, struct session *sess)
 													 GTK_CLIST (sltree)->focus_row));
 
 	new = malloc (sizeof (struct slentry));
+	memset (new, 0, sizeof (struct slentry));
 	new->port = 6667;
-	new->flags = 0;
 	strcpy (new->comment, _("New Server"));
-	new->channel[0] = 0;
-	new->server[0] = 0;
-	new->password[0] = 0;
-	new->nick[0] = 0;
 	text[0] = new->comment;
 
 	if (!parent)
@@ -742,7 +759,7 @@ new_server_clicked (GtkWidget * wid, struct session *sess)
 static void
 new_group_clicked (GtkWidget * wid, struct session *sess)
 {
-	struct slentry *new = 0;
+	struct slentry *new;
 	GtkCTreeNode *node;
 	GtkCTreeNode *sibling;
 	GtkCTreeNode *parent = 0;
@@ -752,13 +769,9 @@ new_group_clicked (GtkWidget * wid, struct session *sess)
 													  GTK_CLIST (sltree)->focus_row));
 
 	new = malloc (sizeof (struct slentry));
-	new->port = 0;
-	new->flags = 0;
+	memset (new, 0, sizeof (struct slentry));
 	strcpy (new->comment, _("New Group"));
-	new->channel[0] = 0;
 	strcpy (new->server, "SUB");
-	new->password[0] = 0;
-	new->nick[0] = 0;
 	text[0] = new->comment;
 
 	if (!sibling)
@@ -870,37 +883,37 @@ close_server_list (int dont_save)
 static void
 connect_auto (struct slentry *conn, struct session *sess)
 {
-	int port;
-	char channel[CHANLEN];
-	char server[132];
-	char password[86];
-	char nick[NICKLEN];
+	server *serv;
 
-	if (!(strlen (conn->server)))
+	if (conn->server[0] == 0)
 		return;
-	safe_strcpy (server, conn->server, sizeof (server));
-	safe_strcpy (password, conn->password, sizeof (password));
-	safe_strcpy (nick, conn->nick, NICKLEN);
-	safe_strcpy (channel, conn->channel, CHANLEN);
-	port = conn->port;
 
 	if (!sess)
 		sess = new_ircwindow (NULL, NULL, SESS_SERVER);
 
-	strcpy (sess->willjoinchannel, channel);
-	strcpy (sess->server->password, password);
-	if (nick[0] == 0)
-		strcpy (sess->server->nick, prefs.nick1);
+	serv = sess->server;
+
+	strcpy (sess->willjoinchannel, conn->channel);
+	strcpy (serv->password, conn->password);
+	if (conn->nick[0] == 0)
+		strcpy (serv->nick, prefs.nick1);
 	else
-		strcpy (sess->server->nick, nick);
-	sess->server->dont_use_proxy = (conn->flags & DONT_USE_PROXY) ? TRUE : FALSE;
+		strcpy (serv->nick, conn->nick);
+	serv->dont_use_proxy = (conn->flags & DONT_USE_PROXY) ? TRUE : FALSE;
 #ifdef USE_OPENSSL
-	sess->server->use_ssl = (conn->flags & USE_SSL) ? TRUE : FALSE;
-	sess->server->accept_invalid_cert =
+	serv->use_ssl = (conn->flags & USE_SSL) ? TRUE : FALSE;
+	serv->accept_invalid_cert =
 		(conn->flags & ACCEPT_INVALID_CERT) ? TRUE : FALSE;
 #endif
 
-	connect_server (sess, server, port, FALSE);
+	if (conn->eom_cmd[0])
+	{
+		if (serv->eom_cmd)
+			free (serv->eom_cmd);
+		serv->eom_cmd = strdup (conn->eom_cmd);
+	}
+
+	connect_server (sess, conn->server, conn->port, FALSE);
 }
 
 /*
@@ -951,6 +964,7 @@ connectnew_clicked (GtkWidget * wid, struct session *sess)
 	GtkCTreeNode *selected;
 	struct slentry *conn;
 	struct slentry myconn;
+	server *serv;
 
 	selected = GTK_CTREE_NODE (g_list_nth (GTK_CLIST (sltree)->row_list,
 														GTK_CLIST (sltree)->focus_row));
@@ -958,11 +972,12 @@ connectnew_clicked (GtkWidget * wid, struct session *sess)
 		return;
 
 	conn = gtk_ctree_node_get_row_data (GTK_CTREE (sltree), selected);
-	if (!(strlen (conn->server)))
+	if (conn->server[0] == 0)
 		return;
-	memcpy(&myconn, conn, sizeof(myconn));
+	memcpy (&myconn, conn, sizeof (myconn));
 
 	sess = new_ircwindow (NULL, NULL, SESS_SERVER);
+	serv = sess->server;
 
 	close_server_list (FALSE);
 	strcpy (sess->server->password, myconn.password);
@@ -971,12 +986,20 @@ connectnew_clicked (GtkWidget * wid, struct session *sess)
 		strcpy (sess->server->nick, prefs.nick1);
 	else
 		strcpy (sess->server->nick, myconn.nick);
-	sess->server->dont_use_proxy = (myconn.flags & DONT_USE_PROXY) ? TRUE : FALSE;
+	serv->dont_use_proxy = (myconn.flags & DONT_USE_PROXY) ? TRUE : FALSE;
 #ifdef USE_OPENSSL
-	sess->server->use_ssl = (myconn.flags & USE_SSL) ? TRUE : FALSE;
-	sess->server->accept_invalid_cert =
+	serv->use_ssl = (myconn.flags & USE_SSL) ? TRUE : FALSE;
+	serv->accept_invalid_cert =
 				(myconn.flags & ACCEPT_INVALID_CERT) ? TRUE : FALSE;
 #endif
+
+	if (myconn.eom_cmd[0])
+	{
+		if (serv->eom_cmd)
+			free (serv->eom_cmd);
+		serv->eom_cmd = strdup (myconn.eom_cmd);
+	}
+
 	connect_server (sess, myconn.server, myconn.port, FALSE);
 }
 
@@ -991,6 +1014,7 @@ connect_clicked (GtkWidget * wid, struct session *sess)
 	GtkCTreeNode *selected;
 	struct slentry *conn;
 	struct slentry myconn;
+	server *serv;
 
 	/* clueless user filter! */
 	if (!strcmp ("root", gtk_entry_get_text ((GtkEntry *) nick1gad)))
@@ -1014,11 +1038,12 @@ connect_clicked (GtkWidget * wid, struct session *sess)
 	conn = gtk_ctree_node_get_row_data (GTK_CTREE (sltree), selected);
 	if (conn->server[0] == 0)
 		return;
-	memcpy(&myconn, conn, sizeof(myconn));
-	safe_strcpy (sess->server->password, conn->password, 85);
-	safe_strcpy (sess->willjoinchannel, conn->channel, CHANLEN);
+	memcpy (&myconn, conn, sizeof (myconn));
+	strcpy (sess->server->password, conn->password);
+	strcpy (sess->willjoinchannel, conn->channel);
 
 	close_server_list (FALSE);
+	serv = sess->server;
 
 	if (myconn.nick[0] == 0)
 	{
@@ -1036,12 +1061,20 @@ connect_clicked (GtkWidget * wid, struct session *sess)
 		}
 	}
 
-	sess->server->dont_use_proxy = (myconn.flags & DONT_USE_PROXY) ? TRUE : FALSE;
+	serv->dont_use_proxy = (myconn.flags & DONT_USE_PROXY) ? TRUE : FALSE;
 #ifdef USE_OPENSSL
-	sess->server->use_ssl = (myconn.flags & USE_SSL) ? TRUE : FALSE;
-	sess->server->accept_invalid_cert =
+	serv->use_ssl = (myconn.flags & USE_SSL) ? TRUE : FALSE;
+	serv->accept_invalid_cert =
 		(myconn.flags & ACCEPT_INVALID_CERT) ? TRUE : FALSE;
 #endif
+
+	if (myconn.eom_cmd[0])
+	{
+		if (serv->eom_cmd)
+			free (serv->eom_cmd);
+		serv->eom_cmd = strdup (myconn.eom_cmd);
+	}
+
 	connect_server (sess, myconn.server, myconn.port, FALSE);
 }
 
