@@ -101,6 +101,7 @@ struct setup
 	GtkWidget *cancel_button;
 
 	GtkWidget *logmask_entry;
+	GtkWidget *logtimestamp_entry;
 
 	struct xchatprefs prefs;
 };
@@ -554,6 +555,7 @@ settings_ok_clicked (GtkWidget * wid, struct session *sess)
 	GETSTR (sess->setup->prefs.quitreason, entry_quit);
 	GETSTR (sess->setup->prefs.partreason, entry_part);
 	GETSTR (sess->setup->prefs.logmask, logmask_entry);
+	GETSTR (sess->setup->prefs.timestamp_log_format, logtimestamp_entry);
 	GETSTR (sess->setup->prefs.nick_suffix, entry_nick_suffix);
 	GETSTR (sess->setup->prefs.stamp_format, entry_stamp_format);
 
@@ -658,7 +660,11 @@ settings_ok_clicked (GtkWidget * wid, struct session *sess)
 	while (list)
 	{
 		s = (struct session *) list->data;
-		if (s->type != SESS_DIALOG && s->type != SESS_SHELL)
+		if (s->type == SESS_DIALOG)
+		{
+			fe_dlgbuttons_update (s);
+		}
+		else if (s->type != SESS_SHELL)
 		{
 			GTK_XTEXT (s->gui->textgad)->tint_red = prefs.tint_red;
 			GTK_XTEXT (s->gui->textgad)->tint_green = prefs.tint_green;
@@ -835,7 +841,7 @@ settings_transparent_check (GtkWidget * widget, struct session *sess)
 	{
 		sess->setup->prefs.transparent = TRUE;
 		gtk_widget_set_sensitive (sess->setup->background, FALSE);
-#ifdef USE_GDK_PIXBUF
+#if defined(USE_GDK_PIXBUF) || defined(USE_MMX)
 		gtk_widget_set_sensitive (sess->setup->check_tint, TRUE);
 #endif
 	} else
@@ -855,7 +861,7 @@ settings_transparent_dialog_check (GtkWidget * widget, struct session *sess)
 	{
 		sess->setup->prefs.dialog_transparent = TRUE;
 		gtk_widget_set_sensitive (sess->setup->background_dialog, FALSE);
-#ifdef USE_GDK_PIXBUF
+#if defined(USE_GDK_PIXBUF) || defined(USE_MMX)
 		gtk_widget_set_sensitive (sess->setup->dialog_check_tint, TRUE);
 #endif
 	} else
@@ -1005,14 +1011,14 @@ settings_create_window_page (GtkWidget * vvbox,
 	gtk_widget_set_sensitive (*transwid, FALSE);
 #endif
 
-#ifdef USE_GDK_PIXBUF
+#if defined(USE_GDK_PIXBUF) || defined(USE_MMX)
 	if (!transparent)
 #endif
 		gtk_widget_set_sensitive (*tintwid, FALSE);
 
 	vbox = settings_create_group (vvbox, _("Tint Setting"));
 
-#ifndef USE_GDK_PIXBUF
+#if !defined(USE_GDK_PIXBUF) && !defined(USE_MMX)
 	gtk_widget_set_sensitive (vbox, FALSE);
 #endif
 
@@ -1025,8 +1031,6 @@ settings_create_window_page (GtkWidget * vvbox,
 
 	gtk_container_add (GTK_CONTAINER (vbox), wid);
 	gtk_widget_show (wid);
-
-	
 }
 
 static void
@@ -1575,6 +1579,8 @@ settings_page_irc_logging (struct session *sess, GtkWidget * vbox)
 	GtkWidget *wid;
 	GtkWidget *tog, *tab;
 
+	gint row_index;
+
 	wid = settings_create_group (vbox, _("General"));
 	tab = settings_create_table (wid);
 	tog = settings_create_toggle (_("Logging"), wid,
@@ -1586,10 +1592,15 @@ settings_page_irc_logging (struct session *sess, GtkWidget * vbox)
 											&(sess->setup->prefs.timestamp_logs));
 
 	add_tip (tog, _("Always apply timestamp to disk logs"));
+	row_index = 0;
 	settings_create_entry (_("Log name mask:"),
 								  sizeof (prefs.logmask) - 1, tab,
 								  prefs.logmask, &sess->setup->logmask_entry,
-								  NULL, NULL, 0);
+								  NULL, NULL, row_index++);
+	settings_create_entry (_("Log timestamp format:"),
+								63, tab,
+								prefs.timestamp_log_format, &sess->setup->logtimestamp_entry,
+								NULL, NULL, row_index++);
 }
 
 static void
