@@ -9,6 +9,9 @@ typedef unsigned long gulong;
 typedef unsigned long guint32;
 typedef unsigned long long guint64;
 typedef float gfloat;
+typedef int gboolean;
+typedef void GIOChannel;
+typedef int GIOCondition;
 
 typedef void (*GFunc) (void *wid, void *data);
 
